@@ -1,10 +1,10 @@
-gg <- function(x,r=1,p=2,usedeldir=TRUE)
+gg <- function(x,r=1,method=NULL,usedeldir=TRUE)
 {
-	dx <- pdist(x,p=p)
+	dx <- as.matrix(dist(x,method=method))
    n <- nrow(dx)
    A <- matrix(0,nrow=n,ncol=n)
    if(is.vector(x)) x <- matrix(x,ncol=1)
-   if(usedeldir && p==2 && ncol(x)==2 && 
+   if(usedeldir && (method=="Euclidean" || is.null(method)) && (ncol(x)==2) && 
 	  (length(.find.package("deldir",quiet=TRUE))>0)){
 	  require(deldir)
 	  del <- deldir(x[,1],x[,2])
@@ -12,7 +12,7 @@ gg <- function(x,r=1,p=2,usedeldir=TRUE)
 	    i <- del$delsgs[edge,5]
 	    j <- del$delsgs[edge,6]
 		 d1 <- r*dx[i,j]/2
-		 d <- pdist((x[i,]+x[j,])/2,x,d=ncol(x),p=p)
+		 d <- dist((x[i,,drop=FALSE]+x[j,,drop=FALSE])/2,x,method=method)
 		 d[i] <- Inf
 		 d[j] <- Inf
 		 if(!any(d<d1)){
@@ -26,7 +26,7 @@ gg <- function(x,r=1,p=2,usedeldir=TRUE)
 		 for(j in setdiff(1:n,i)){
 			d1 <- r*dx[i,j]/2
 			d1 <- round(d1,10)
-			d <- pdist((x[i,]+x[j,])/2,x,d=ncol(x),p=p)
+			d <- dist((x[i,,drop=FALSE]+x[j,,drop=FALSE])/2,x,method=method)
 			d <- round(d,10)
 			d[i] <- Inf
 			d[j] <- Inf
@@ -41,7 +41,6 @@ gg <- function(x,r=1,p=2,usedeldir=TRUE)
 	g <- graph.adjacency(A,mode="undirected")
 	g$r <- r
 	g$layout <- x
-	g$p <- p
    g
 }
 
